#
# spec file for package python-fixtures
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-fixtures
Version:        3.0.0
Release:        3.2
Summary:        Fixtures, reusable state for writing clean tests and more
License:        Apache-2.0 or BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://launchpad.net/python-fixtures
Source:         https://pypi.io/packages/source/f/fixtures/fixtures-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-mock
BuildRequires:  python-pbr >= 0.11
BuildRequires:  python-six
BuildRequires:  python-testtools >= 0.9.22
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-discover
BuildRequires:  python-unittest2
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif
Requires:       python-six
Requires:       python-testtools >= 0.9.22

%description
Fixtures defines a Python contract for reusable state / support logic,
primarily for unit testing. Helper and adaption logic is included to make it
easy to write your own fixtures using the fixtures contract. Glue code is
provided that makes using fixtures that meet the Fixtures contract in unittest
compatible test cases easy and straight forward.

%prep
%setup -q -n fixtures-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
make check

%files
%defattr(-,root,root,-)
%doc Apache-2.0 BSD COPYING NEWS README
%{python_sitelib}/*

%changelog
* Mon Jun 20 2016 dmueller@suse.com
- update to 3.0.0:
  * Release 3.0.0
  * Fixup the MonkeyPatch patch
  * Tweak the new tests for consistency
  * Update the semantics on _fixtures.MonkeyPatch
  * Avoid old versions of pbr - we require modern releases
  * Correct MockPatchMultiple example
  * Ignore .tox
  * MonkeyPatch staticmethod
  * Drop support for Python 3.2. It's history
  * Fix print in README
  * Add CompoundFixture
  * Tweak hacking docs
  * Fix "propagate" spelling everywhere
  * Missed one: propogate -> propagate
  * Spelling and lint fixes
  * Release 1.4
  * Trivial pep8 fix to logger.py
  * FakeLogger: Mis-formatted log messages will raise Exception
  * Use mock in preference to unittest.mock
  * Add a .travis.yml
  * Note how to push on releases
* Tue Sep  1 2015 tbechtold@suse.com
- Add missing python-six Requires and BuildRequires
* Fri Jul  3 2015 dmueller@suse.com
- update to 1.3.1:
  * Clarify the intent around _setUp
  * Handle BaseException resource leaks as well
  * Remove trailing whitespace
  * Deal with resource leaks during setUp
  * Missed NEWS entry
  * Fine tune the mock patch
  * Add a new mockpatch fixture
  * Document where the project home and source are
  * Ignore built things
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 1.2.0:
  * Release 1.2.0
  * Add a warnings module capture fixure
  * Use universal wheels
- additional changes from version 1.1.0:
  * Release 1.1.0 and use pbr 0.11 features
  * Missing NEWS entry
  * add tox.ini file
  * Fixed test performance on Python 3.5
  * Add NEWS for FakeLogger formatter
  * allow the specification of a custom log formatter
- set a minimum version for python-pbr
- reenable the tests via make check:
  python-testrepository is not needed anymore
* Mon Mar  2 2015 p.drouand@gmail.com
- Disable tests and python-testrepository require to avoid a build
  cycle
* Thu Jan  8 2015 tbechtold@suse.com
- update to version 1.0.0:
  * remote copy/paste from another project
  * Add support for datefmt in FakeLogger
  * Migrate to git and pbr
- Disable parallel builds for now due to some test failures.
- Update BuildRequires
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 0.3.16:
  * Fixed 0.3.15 on Python 2.6 - version info is a plain tuple there.
  * ``FakePopen`` now supports being called under a context manager (IE: with).
  * ``FakeProcess`` now supports kill().
  * ``FakeProcess`` wait() now supports arguments added in Python 3.
  * ``MonkeyPatch`` now preserves ``staticmethod`` functions.
- Add python-testtools as Requires
* Tue May 20 2014 dmueller@suse.com
- move unittest2 to the SLE11-specific requires (not needed on python 2.7+)
* Tue Apr  8 2014 dmueller@suse.com
- fix license declaration
* Fri Mar  7 2014 speilicke@suse.com
- Fix the real issue instead
* Fri Feb 14 2014 dmueller@suse.com
- only run testsuite when it actually runs
* Fri Feb 14 2014 speilicke@suse.com
- Run testsuite
* Wed Sep  4 2013 speilicke@suse.com
- Update to version 0.3.14
  + FakePopen can now override the returncode attribute.
- Changes from version 0.3.13:
  + Documentation hopefully covers TestWithFixtures a little better.
  + FakePopen now accepts all the parameters available in Python 2.7.
  + FakePopen now only passes parameters to the get_info routine if the
    caller supplied them.
  + setup.py now lists the testtools dependency which was missing.
* Mon Jan 14 2013 saschpe@suse.de
- Initial version
